@@ -1,14 +1,14 @@
 """
-ytdlmusic scripts
+ytdlmusic entrypoint
 """
 
 import sys
+import colorama
 from ytdlmusic.ytdlmusic import job
 from ytdlmusic.update import update, fullupdate
 from ytdlmusic.batch import launch_batch
 from ytdlmusic.print import (
     print_error,
-    print_bad_launch,
     print_version_ytdlmusic,
     print_version_dependencies,
     print_licence,
@@ -20,12 +20,14 @@ from ytdlmusic.params import (
     is_batch,
     param_batch,
     param_search,
-    check_classic_params,
 )
 
 
 def ytdlmusic():
-
+    """
+    ytdlmusic entrypoint
+    """
+    colorama.init()
     """
     entry point from ytdlmusic
     """
@@ -43,6 +45,6 @@ def ytdlmusic():
         else:
             job(param_search())
         sys.exit(0)
-    except Exception as err:
-        print_error(err)
+    except Exception:
+        print_error()
         sys.exit(1)
