@@ -1,18 +1,17 @@
 """
 main class ytdlmusic
 """
-
 import sys
+import os
+from ytdlmusic.download import download_song
+from ytdlmusic.print import print_error
+from ytdlmusic.params import is_tag, is_batch, my_colored_emoji
 from ytdlmusic.search import search
 from ytdlmusic.choice import choice
 from ytdlmusic.file import (
     determine_filename,
     determine_finame_from_tag,
 )
-from ytdlmusic.download import download_song
-from ytdlmusic.print import print_error
-from ytdlmusic.params import compute_args, is_tag, is_batch
-import os
 
 
 def job(keywords):
@@ -34,10 +33,8 @@ def job(keywords):
                 newfilename = determine_finame_from_tag(filename)
                 os.rename(filename, newfilename)
                 filename = newfilename
-            print(filename + " is ready")
-            return filename
-    except Exception as err:
-        print_error(err)
+            print(my_colored_emoji("\u2705 ", filename + " is ready", "green"))
+    except Exception:
+        print_error()
         if not is_batch():
             sys.exit(1)
-        return ""
